@@ -1,14 +1,15 @@
+/*
+ * @Author: tzw
+ * @Date: 2021-10-31 23:26:50
+ * @LastEditors: tzw
+ * @LastEditTime: 2021-11-03 23:21:38
+ */
 use std::collections::HashMap;
 use serde::{Deserialize, Serialize};
 
-
-// * @Author: tzw
-//  * @Date: 2021-10-21 22:24:44
-//  * @LastEditors: tzw
-//  * @LastEditTime: 2021-10-22 00:06:07
-
-
-/// eventuate 消息定义
+/**
+eventuate 消息定义
+*/
 pub trait Imessage{
      fn get_id(&self) -> Option<String>;
      fn get_headers(&self) -> Option<HashMap<String, String>>;
